@@ -17,7 +17,8 @@
 
 QTM_USE_NAMESPACE;
 
-class Station {
+class Station : public QObject {
+    Q_OBJECT;
 public:
     Station(QString, QString, float, float, int, int);
     virtual ~Station();
