@@ -2,8 +2,8 @@
 
 GPSPosition::GPSPosition(QObject *parent) :
     QObject(parent) {
-
-    QGeoPositionInfoSource * location = QGeoPositionInfoSource::createDefaultSource(this);
+    tolerance = 50;
+    location = QGeoPositionInfoSource::createDefaultSource(this);
     connect(location, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(onPositionUpdated(QGeoPositionInfo)));
     location->startUpdates();
     location->setUpdateInterval(30000);
@@ -18,16 +18,28 @@ qreal GPSPosition::getLongitude() const {
     return coordinate.longitude();
 }
 
+void GPSPosition::setTolerance(qreal newTolerance) {
+    tolerance = newTolerance;
+}
+
 QGeoCoordinate GPSPosition::getCoordinate() const {
     return coordinate;
 }
 
 void GPSPosition::onPositionUpdated(QGeoPositionInfo position) {
     coordinate = position.coordinate();
-    qDebug() << "Position updated : " << coordinate << endl;
+    if (coordinate.distanceTo(lastEmitted) > tolerance) {
+        lastEmitted = coordinate;
+        emit movedTolerance();
+    }
+    qDebug() << "Position updated : " << coordinate;
 }
 
 GPSPosition& GPSPosition::getInstance() {
     static GPSPosition instance;
     return instance;
 }
+
+void GPSPosition::requestUpdate() {
+    location->requestUpdate();
+}
