@@ -19,18 +19,23 @@ public:
     qreal getLatitude() const;
     qreal getLongitude() const;
     QGeoCoordinate getCoordinate() const;
+    void setTolerance(qreal newTolerance);
 
 signals:
+    void movedTolerance();
 
 public slots:
+    void requestUpdate();
+
+private slots:
     void onPositionUpdated(QGeoPositionInfo);
 
 private:
     GPSPosition(QObject *parent = 0);
-
+    QGeoPositionInfoSource * location;
     QGeoCoordinate coordinate;
-
-
+    QGeoCoordinate lastEmitted;
+    qreal tolerance;
 };
 
 #endif // GPSPOSITION_H
