@@ -6,6 +6,8 @@
 
 #include "gpsposition.h"
 
+#include <QTranslator>
+
 int main(int argc, char *argv[])
 {
     QTextStream out(stdout);
@@ -15,6 +17,11 @@ int main(int argc, char *argv[])
     QApplication ::setOverrideCursor(QCursor(Qt::BlankCursor));
 #endif
 
+
+    QTranslator translator;
+    qDebug() << translator.load(":/bicimobile_" + QLocale::system().name());
+    app.installTranslator(&translator);
+
     StationsState * state = new StationsState();
 
     UpdaterThread * updaterThread = new UpdaterThread(state);
