@@ -9,6 +9,11 @@ MapWidget::MapWidget(const QGeoCoordinate& station, const QGeoCoordinate& user,
     setMinimumSize(400,400);
 
     fetchMap(size(), station, user);
+
+    QTimer * updateTimer = new QTimer(this);
+    connect(updateTimer, SIGNAL(timeout()), &GPSPosition::getInstance(), SLOT(requestUpdate()));
+    connect(&GPSPosition::getInstance(), SIGNAL(movedTolerance()), this, SLOT(fetchMap()));
+    updateTimer->start(15000);
 }
 
 void MapWidget::fetchMap(const QSize& size, const QGeoCoordinate& station, const QGeoCoordinate& user) {
